from setuptools import setup
classifiers = [
   'Development Status:: 5 - Production/Stable',
   'Intended Audience :: Education',
   'Operating System :: Microsoft :: Windows :: Windows 11',
   'Topic :: Utilities',
   'License :: OSI Approved :: MIT License',
   'Programming Language :: Python 3.0.9',
]
setup(
    name='mypackscal',
    version='0.0.1',
    description='this is a trial package used for calculation.',
    url='',
    author='Shreyas MR',
    author_email='shreyasmr13@gmail.com',
    licence='MIT',
    packages=['mypackscal'],
    install_requires=[]
)